==> vodex-1.0.11.tar.gz: vodex-1.0.11/docs/index.md <==
# <u>VoDEx</u>: <u>Vo</u>lumetric <u>D</u>ata and <u>Ex</u>periment Manager

[![License BSD-3](https://img.shields.io/pypi/l/vodex.svg?color=green)](https://github.com/LemonJust/vodex/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/vodex.svg?color=green)](https://pypi.org/project/vodex)
[![Python Version](https://img.shields.io/pypi/pyversions/vodex.svg?color=green)](https://python.org)
[![tests](https://github.com/LemonJust/vodex/workflows/tests/badge.svg)](https://github.com/LemonJust/vodex/actions)
[![codecov](https://codecov.io/gh/LemonJust/vodex/branch/main/graph/badge.svg)](https://codecov.io/gh/LemonJust/vodex)
[![napari hub](https://img.shields.io/endpoint?url=https://api.napari-hub.org/shields/napari-vodex)](https://napari-hub.org/plugins/napari-vodex)

Vodex is a Python library that aims to simplify the process of synchronizing volumetric imaging data with experimental conditions, behavior and physiological data.
It provides tools for automating the process of collecting, storing and retrieving information about the experiment in a structured way and helps to reduce errors and improve reproducibility.
The library is open-source and is designed to be easy to integrate into existing analysis pipelines.
It also includes a [napari](https://napari-hub.org/plugins/napari-vodex) plugin for interactive usage with a GUI.
Overall, it aims to make the process of handling and analyzing functional volumetric imaging data more efficient and reliable.

<p align="center">
  <img src="assets/vodex_infographics.PNG" alt="cover" width="800"/>
</p>

## Quick Start
To get started with `VoDEx`,
please see [Quick Start](https://lemonjust.github.io/vodex/qstart/) and [Examples](https://lemonjust.github.io/vodex/examples/).

## API Reference
[API](https://lemonjust.github.io/vodex/api/) contains the technical implementation of the `VoDEx` project code.

## Contributing

Contributions are very welcome. Please see [Contributions](https://lemonjust.github.io/vodex/contribute/) for more details.

## Data

Some toy datasets are available in [Data](https://lemonjust.github.io/vodex/data/).

## License

Distributed under the terms of the [BSD-3] license,
`vodex` is free and open source software

==> vodex-1.0.12.tar.gz: vodex-1.0.12/docs/index.md <==
# <u>VoDEx</u>: <u>Vo</u>lumetric <u>D</u>ata and <u>Ex</u>periment Manager

[![License BSD-3](https://img.shields.io/pypi/l/vodex.svg?color=green)](https://github.com/LemonJust/vodex/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/vodex.svg?color=green)](https://pypi.org/project/vodex)
[![Python Version](https://img.shields.io/pypi/pyversions/vodex.svg?color=green)](https://python.org)
[![tests](https://github.com/LemonJust/vodex/workflows/tests/badge.svg)](https://github.com/LemonJust/vodex/actions)
[![codecov](https://codecov.io/gh/LemonJust/vodex/branch/main/graph/badge.svg)](https://codecov.io/gh/LemonJust/vodex)
[![napari hub](https://img.shields.io/endpoint?url=https://api.napari-hub.org/shields/napari-vodex)](https://napari-hub.org/plugins/napari-vodex)

Vodex is a Python library that aims to simplify the process of synchronizing volumetric imaging data with experimental conditions, behavior and physiological data.
It provides tools for automating the process of collecting, storing and retrieving information about the experiment in a structured way and helps to reduce errors and improve reproducibility.
The library is open-source and is designed to be easy to integrate into existing analysis pipelines.
It also includes a [napari](https://napari-hub.org/plugins/napari-vodex) plugin for interactive usage with a GUI.
Overall, it aims to make the process of handling and analyzing functional volumetric imaging data more efficient and reliable.

<p align="center">
  <img src="assets/vodex_infographics_w_data_and_labels.PNG" alt="cover" width="1200"/>
</p>

## Quick Start
To get started with `VoDEx`,
please see [Quick Start](https://lemonjust.github.io/vodex/qstart/) and [Examples](https://lemonjust.github.io/vodex/examples/).

## API Reference
[API](https://lemonjust.github.io/vodex/api/) contains the technical implementation of the `VoDEx` project code.

## Contributing

Contributions are very welcome. Please see [Contributions](https://lemonjust.github.io/vodex/contribute/) for more details.

## Data

Some toy datasets are available in [Data](https://lemonjust.github.io/vodex/data/).

## License

Distributed under the terms of the [BSD-3] license,
`vodex` is free and open source software
